bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 25. Aventiure
___________________________________________________ #### Auentewor wie sich die chünig von den Hewonenn #### huobenn
| ### Nv lazzen das belaiben wie si gebaren bie ### hoch gemuter rekchen die gefuoren nie ### so rechte herleichn– in dhaines chünigs lant ### si hetten was si wolden dar zu waffen vn– gewant
###### 1540 | ### Der vogt von dem Rein chlaidet sein man ### sechtzig vnd tawsent als ich vernomen han ### vnd newne tawsent chnechte gen der hochtzeit ### die si dahaime liezzen die bewainten ez seit
###### 1541 | ### Do truog man die geraite ze Wuormtz vbir den hof ### da sprach do von Speier ain alter bischoff ### zu der alten chü[97v]niginne vnser frewnt die wellent varen ### hin zer hochtzeite got muzze ir er wol bewaren
###### 1542 | ### Do sprach zu ir du edel Vte ### ir möchte noch beleiben holde guote ### ich sach heint in treume vil angestlichhe not ### wie alles daz gefügel in disem lande lait tot
###### 1543 | ### Swer gelawbet trawmen sprach do Hagene ### der enwais der rechten maere nicht zu sagene ### wenne ez im nach dem ern vollichen ste ### ja wil ich daz meine herre ze houe nach vrlaup ge
###### 1544 | ### Wir sullen gern reiten in Etzln lant ### so mag wol chünigen dienen guter helde hant ### da wir do müzzen schawen Chrimhilden hochtzeit ### Hagen riet die raise iedoch gerawe ez in seit
###### 1545 | ### Ez het ez wider rate newr das Gernot ### mit vns efügen sprechen im sere missebot ### er mant in Seifrides frawn Chrimhilden man ### er sprach do vorz wil Hagen die grozzen houe raisen lan
###### 1546 | ### Do sprach der von Tronge [98r]durch vorcht ez nieman tu ### swenne ir helde wellet so sult ir greiffen zu ### ia reite ich mit ew in Etzln lant ### seit wart von im verhawen manig helm vnd rant
###### 1547 | ### Dew scheff beraitet waren ze varen vbir Rein ### swas si chlaider beten die trug man dar ein ### si waren vil vnmüssig vor abendes zeit ### doch chomen si von haus vil harte froleich seit
###### 1548 | ### Gezelt vnd hütten si spinen an daz gras ### an der halb des Reines do daz geschehen was ### den chünig pat noch beleibn– sein vil schones weip ### si traute noch des nachtz seinen waetlichn– leip
###### 1549 | ### Floiten vn– videln hup si des morgens fru ### da si da hin musten do griffen si do zu ### swer hete lieb an arme der traute frewdes leip ### des schiet seit mit laide des chünig Etzln weip
###### 1550 | ### Ruomolt der chuochenmaister ein vil chüne man ### der nan sein herrn haimleich dan ### do sagt er dem chünig taugen seinen muot ### er sprach des muozz [98v]ich trawren daz ir die houe reizze tut
###### 1551 | ### Ich <han> ewch vil gewarent vnd auch genug gemant ### er sprach wem welt ir lazzen leute vnd lant ### daz niemant chan erwenden ew rekchn– tumbn– mut ### dew Chrimhilde maere nie gedauchtn– si mich gut
###### 1552 | ### Daz lant sei dir enpholhn– vnd andern meinen man ### die ich haime lazze vnd alles daz ich han ### mein chint vnd meine gesinde vnd meiner frawen leip ### ia getut vns nimmer laide dez chünig Etzln weip
###### 1553 | ### E daz si schieden danne der chunig zu rate gie ### mit seinen hochsten mannen vnberichtet er nicht lie ### lant vnd burge die der solden pflegen ### den liez er ze huote vil mangen auzerwelten degen
###### 1554 | ### Die ros beraitet waren der chunigen vn– ir man ### mit minecleichn– chüssen schiede vil manger dan ### dem in hohn– muote lept do der leip ### daz must seit bewainen vil manich waetleich weip
###### 1555 | ### Wuoffen vnd [99r]wainen des hort man genug ### ir chint die chüniginne zu dem chünig auff armen trug ### wie welt ir im verwaisen vnser paider leip ### ir solt durch vns belaibn– so sait daz iamerhafte weip
###### 1556 | ### Ir sult nicht fraw wainen durch den willen meine ### ir sult in hoben muote hie haime an angst sein ### wir chormen schir wider mit frewden wol gesunt ### si schiedn– minnicleichn– von ir frivndn– sa ze stunt
###### 1557 | ### Do man die snellen rekchn– sach zu den rossen gan ### do chost man wainende vil mange frawen stan ### daz ir vil langes scheiden sagt in wol ir mut ### auff grozzen schaden ze chomene daz hertzen niemant sanfte tut
###### 1558 | ### Die snellen Borgonden sich an hubn– ### da wart in dem lande ein michel üben ### paidentbalbn– des Raines wainten weip vnd man ### swie dort ir volche getarte si furen fröleich dann
###### 1559 | ### In der selben tzeiten [99v]was der gelaube nach chrankch ### doch fruomtens ainen capplan der in messe sanch ### der <chome> gesunder wider wan der vil chaume entran ### die andern musten alle da zen Heunen bestan
###### 1560 | ### Do schikchten si ir raise gen den Nevnen dan ### auf durch Osterfrankchn– der dreier chünig man ### dar laite si do Hagen dem was ez wol bechant ### Danchwart was marsalch der helt von Burgunden lant
###### 1561 | ### Do si durch Swanvelde riten von Osterffranchen ### do mocht man si chiesen an herleiehen siten ### di fürsten vnd er ir mage die helde lobesam ### an dern tzwelften morgen der chunig ze Tunawe quam
###### 1562 | ### Do rait von Tronge Hagen ze aller foderst ### ez was den Nybelungen ein hilfleicher trost ### do stunt der degen chüne nider auf den sant ### sein ros er harte balde zu einem pawm gepant
###### 1563 | ### Daz wazzer was engozzen die scheff verporgen ### ez chome den Nybelungen ze grozzen sorgen ### wie si chomen [roor]vbir den wach der was gar ze berait ### do erbant zu der erden manich ritter gemait
###### 1564 | ### Laider sprach so Hagen mag dir wol hie geschehen ### voget von dem Reine nu möcht du selbe sehhen ### daz wazzer ist engozzen vil starche ist im sein flut ### ich waen wir hie verliesen noch hewte vil mangen ritter gut
###### 1565 | ### Waz weizzet ir mir Hagen sprach do der chünich her ### durch ewr selbs tugent vntrost vns nicht mer ### den furt sult ir vns suchn– hin vbir das lant ### daz wir hinnen bringen baidew ros vnd gewant
###### 1566 | ### Ja en ist mir sprach da Hagen mein lebn– nicht so lait ### daz ich mich ertrenkchn– in disem wage berait ### er sol von meinen handen ersterbn– manich man ### in Etzln landen des ich vil guten willen han
###### 1567 | ### Beleibet bei dem wazzer ir stoltzen ritter gut ### ich wil die vergen suchen selbe pei der flut ### die vns vbir bringen in das Etzln lant [100v] ### Hagen der chüne nam seinen schilde an die hant
###### 1568 | ### Der holt vil gut gewaeffen an seinen leip trug ### vnd ainen helm auf seinem hawpt lauter genuch ### do trug er ob der prum aine waffen also prait ### daz zu seinen eken hart pitterleich snait
###### 1569 | ### Er suchte nach den vergen wider vnd dan ### er horte wazzer giezzen <lozzen> er began ### in ainem schonen prunn daz taten weisew weip ### die chülten sich dar ynne vn– bedawten iren leip
###### 1570 | ### Hagen wart ir ynne er slaich in sanfte nach ### do si den helt ersahen do ward in von in gach ### daz si im entrunnen des waren si vil her ### da nam er ir gewaete der helt der schadet in nicht mer
###### 1571 | ### Da sprach das aine merweip die was Haderburg genant ### her Hagen gebt uns wider vnser gewant ### do ir vns edel rekch gebt wider vnser [101r]wat ### ich sag ew wie ewer raise hin zen Heunen ergat
###### 1572 | ### Si swebten so die vogle vor im auf der flut ### des dauchten in ir list starkch vnd gut ### swas si im sageten er gelawbt ins dester pas ### des er an si gerte ir ainew sagt im daz
###### 1573 | ### Si sprach ir mügt wol reiten in Etzln lant ### des sei mein trewe bürg mein haubt sei ewr phant ### daz held nie gefuoren in dhaine reiche pas ### nach also grozzen ern ir solt wol gelauben daz
###### 1574 | ### Die rede waz da Hagen in seinem hertzen her ### er gab ir wider ir chlaider der helt sampt sich nicht mer ### do si do an geleten ir wunderleich gewant ### do sagten si im die raise in daz Etzln lant
###### 1575 | ### Do sagt daz ander merweip die hiez Winelint ### ich wil dich waren das Adrianes chint ### durch der waete liebe hat mein muome dir gelegen ### vn– chuompst [101v]zu den Heunen so pist du sere betrogen
###### 1576 | ### Do solt du cheren wider daz ist an der tzeit ### wande ir helde chüne also geladet seit ### daz ir ersterben müset in der Heunen lant ### swelch dar gereitent die hant den tot an der hant
###### 1577 | ### Des antwort Hagen ir trieget an not ### wie chünde sich gefügen daz wir alle tot ### zer hochtzeit gelegen durch iemandes has ### do begunde si im die maer sagen chundleich pas
###### 1578 | ### Si sprach nu merchet Hagen ia muoz ez also wesen ### daz ewer dhainer da nicht chan genesen ### wan aine des chünigs cappelan da bei sei ew bechant ### der chuompt gesunder wider in des Günthers lant
###### 1579 | ### Da sprach in grimmem mute der chüne Hagen ### daz waer meinen herrn müleich ze sagen ### daz wir zen Heunen solden fliezzen alle den leip ### nv zaig vns vbir daz wasser das aller weisiste weip
###### 1580 | ### Si sprach seit ir der verte nicht wellet habn– [102r]rat ### swa ienhalbe pei dem wazzer ain berberge stat ### dar inne ist ein verg vnd niendert anderswo ### der maere der er fragt der gelaubet er sich sa
###### 1581 | ### Dem vngemuten rekchen sprach ir ainer nach ### nu baitet nah her Hagen lat ew nicht sein ze gach ### vernempt pas div maere wir ir chömt vbir sant ### dirr marcherre der ist Else genant
###### 1582 | ### Dem pruder ist geheisen Gelpfrat ### ein vogt in Baierlande dez ez ew muoleich stat ### welt ir durch sein marche ir solt ew wol bewaren ### vn– sult auch mit dem vergen vil beschaidenleich varen
###### 1583 | ### Der ist so grimmes mutes er lat ew nicht genesen ### iren welt mit guten sinnen bei dem holt wesen ### welt ir daz er euch fuore so gibt im den solt ### er hütet ditz landes vnd Gelpfrade holt
###### 1584 | ### Vnd cham ere nicht vil schiere so ruffet vbir fluot ### iocht ir seit Amelrinch <[102v]> daz was ein reck gut ### der durch veintscheft rawmt dise lant ### so kuompt euch der verge als im der nam wirt genant
###### 1585 | ### Der übermut Hagen den frawen do neyg ### des rates vnd der lere der helt vil still sweig ### da ging er bey der flute hoher an den sant ### do er anderhalp ein herwerg vant
###### 1586 | ### Er begond ruffen vaste über fluote ### hol mich hy vorge sprach der degen gute ### so gib ich dir ze mite vol gold einen pauch vil rot ### ia ist mir dirr verte daz wiß werlichen not
###### 1587 | ### Der verig was so reich daz im nicht dienen zäm ### da von er lon vil selten von ymant da genam ### auch warn seine knecht vil hochgemut ### noch stund allz Hagen dishalb der flut
###### 1588 | ### Da da ruft er mit der krefte daz aller wag erdoz ### wann des heldes sterck was michel vnd groz ### nu hol mich Amelreichen des herrn Elsen man ### der von disen landen [103r]durch groß veintscheft entran
###### 1589 | ### Vil hoch an seinem swerte er im den pauchk do pot ### vil licht vnd vil schon was er von golde rot ### daz er in überfürte in des Elsen lant ### der übermut verge nam daz ruder selb in dy hant
###### 1590 | ### Auch was der selb verg vil mülich gesit ### zu girde nach großem gut vol bösez ende gibt ### da wänt er verdinen daz Hagen golt so rot ### daz laid er von dem degen sint den grimmigen tot
###### 1591 | ### Der verg zog genote hin uber an daz lant ### den er da nennen hort do er des nicht <en> vant ### ez müet in hart ser als er Hagen sach ### der helde wider den recken in vil großen zorn–
###### 1592 | ### Ir mügt wol sein geheißen Armelreich benamen ### des ich mich hy verwen dem seit ir vngleich ### von vater vnd von muter was er der bruder mein ### nu ir mich sust betrogen habt ir muoßt dishalben sein
###### 1593 | ### Nein durch got den reichen sprach do Hagen ### ich pin ein frömder [103v]reck vnd sorg auff degen ### nu nempt hin minniclelich mein ellendes solt ### daz ir mich füret über ich wil euch ymmer wesen holt
###### 1594 | ### Des antwort der verg ia kan ez nichte gesein ### ez hab vinande den liben hern– mein ### frivnde fur in diß lant ### als lip dir sey ze leben so trit bald auß an daz lant
###### 1595 | ### Des entut ir nicht sprach Hagen mir ist der reyse not ### vnd nempt von mir ze lon disen pouch von golde rot ### vnd fürt mir über tausent ros vnd also manchen man ### entrewn– sprach der verg daz wirt nymmer getan
###### 1596 | ### Er hub ein starckez ruder michel vnd breyt ### vnd slug ez auff Hagen des was er vngemeit ### daz er in dem schiff straucht auff seine kny ### so rechte grimmer verge kome dem helde von Trong nie
###### 1597 | ### Er wold baz ertzürnen den vngermuten gast ### do slug er einen schalten daz da gar zerprast ### Hagen über daz heupt er was ein starcker man ### da von der Elsen verg großen schaden gewan
###### 1598 | ### Mit grymmigem mute des [104r]keünen Hagen hant ### greiff zu einer scheiden do er seine waffen vant ### er slug im ab daz hewpt vnd warff ez an den grunt ### dy mer wurden schir den Burgunden kunt
###### 1599 | ### An den selben stunden do er den vergen slug ### daz schiff floz hinnaw daz was im leit genug ### e ers gericht wider müden er began ### da tzoch vil krefticklich zu des Günthers man
###### 1600 | ### Hagen was vil ring des starcken vergen val ### da kert er hart bald daz waßer hin zetal ### da vand er seinen herren an dem stade stan ### da ging im engegen manig weydlich man
###### 1601 | ### Mit gruß in wol enpfingen dy selben ritter gut ### do sahen sy in dem schiff noch richen daz blut ### von einer starcken wunden dy er dem vergen slug ### da von so muß Hagen hören fragen genug
###### 1602 | ### Do der künig Günther daz heiß blut ersach ### swebende in dem schiff wy bald er do sprach ### wan saget ir mir Hagen war ist der verge nu kumen ### ewer starcken ellen ym [104v]daz leben hat benomen
###### 1603 | ### Do sprach er lawgenlichen do ich daz schiff da vant ### bey einer wilden widen da lost ez mein hant ### ich han keinen vergen nindert hy gesehen ### ez ist auch nimant laide von meinen schulden hy geschehen
###### 1604 | ### Do sprach von Burgundn– der starcke Gernot ### hewt muß ich sorgen auff liber frewnde tot ### sint wir der schifflewt zu dem scheff nymant han ### wy wir nu komen über daz waßer darümb muß ich frewd lan
###### 1605 | ### Vil laut riff do Hagen legt nider auff daz gras ### ir knechte da gereit ia gedenck ich daz ich was ### der allerbeste verge den man bey dem Rein vant ### ich getraw euch wol füren über in des Gelpfrades lant
###### 1606 | ### Do sy gewärlich komen über flut ### dy ros sy gar an slugen der swimmen daz wart gut ### wan in der starcken vnden keines da benam ### etlichz ran verren als ez ir müde gezam
###### 1607 | ### Da trugen sy zu dem schiff ir golde vnd auch ir wat ### sind daz sy der verte nicht möchten baben [105r]rat ### Hagen was da meister des furt er über sant ### vil manchen künen recken in daz vnkunde lant
###### 1608 | ### Zu dem ersten bracht er über tawsent ritter her ### vnd sechtzig seiner degen dennoch was ir mer ### newn tawsent knechte furt er an den sant ### des tages was vil vnmüssig des vil künen Hagen hant
###### 1609 | ### Daz schiff zu seiner leng was starck weit vnd groz ### des in dem geding manig helt genoz ### ez trug wol mit ein ander vir hundert über flut ### an rimen musten tzihen des tages manig recken gut
###### 1610 | ### Do er sy wol gesunt bracht über dy flut ### do gedacht frömder mere der snell degen gut ### dy im e da sagten dy wilden mere weip ### des hett des künigs capplan vil nach verlorn– den leip
###### 1611 | ### Bey dem cappelsaüm er den priester vant ### heiligtum genug lag vnter seiner hant ### des mocht er nicht genißen do in Hagen ersach ### der vil <arme> capplan must leiden vngemach
###### 1612 | ### Er swang in auß dem schiff [105v]dar tzu was im gach ### da riffen ir genug vach herr vach ### Geiseler der iung tzürnen do began ### darvmb er ez nicht laßen wolde daz was im leyd getan
###### 1613 | ### Do sprach von Burgunden der starcke Gernot ### waz hilfft euch nu Hagen des capplans tot ### tet ez anders ymand ez schold euch wesen leyt ### vmb welch schuld habt ir dem prister widerseyt
###### 1614 | ### Der pfaff swam genote er wold sein genesen ### ob ym ymand hülff des mocht da nicht gewesen ### wan– der grimm Hagen tzornig was genug ### er stiß in zu dem grund daz daucht sy michel vngefug
###### 1615 | ### Do der arme priester der hilff nicht ensach ### da kert er wider uber des leid er vngemach ### wy er do nicht swimmen konde im halff dy gotes hant ### daz er kam wol gesunder hinüber an daz lant
###### 1616 | ### Da stund der arme prister vnd schawet sein gewant ### da bey sach wol Hagen daz er wär vngewant ### daz im e da sagte dy weisen mer[106r]weip ### er gedacht diser degen muß verlisn– den leip
###### 1617 | ### Do sy daz schiff entluden vnd gar getrugen dan ### waz sy darauff hetten der dreier künig man ### Hagen ez schrit zu stücken vnd stiß ez an dy flut ### des hettn– michel wunder dy recken gut
###### 1618 | ### Warvmb tut ir daz bruder sprach do Danchwart ### wye schüll wir kumen uber so wir dy widervart ### riten von den Hewnen wider an den Rein ### seht do sagt im Hagen daz des nicht kond gesein
###### 1619 | ### Do sprach der helt von Trong ich tun ez auff den wan ### ob wir an diser verte keinen tzagen hagen ### der vns entrinnen wöll durch tzaglich not ### der muß an disem wage doch ligen schemlichen tot
###### 1620 | ### Sy furten mit in einen von Burgunden lant ### der was ein helt zen handen Volker was er genant ### der redet spehlich seinen mut ### waz y begond <Hagen> daz daucht den vidler gut
###### 1621 | ### Do des küniges capplan daz schiff zuhawen sach ### hin wider über daz waßer er zu Hagen [106v]sprach ### ir mörder vngetrewer waz hett ich euch getan ### daz ir mich on schuld ertrenckt wollt han
###### 1622 | ### Des antwort im Hagen nu laßt dy red wesen ### mir ist leit auff mein trew daz ir seyt genesen ### hy vor meinen handen daz wißt sunder an spot ### do sprach der arm capplan des wil ich ymmer loben got
###### 1623 | ### Ich fürcht euch nu vil kleine des schüllet ir sicher sein ### nu vart ir zu den Hewnen so wil ich an den Rein ### got en laß euch nymmer zu dem Rein wider kurmen ### des wünschen ich euch vil ser ir hett mir nahen den leip benomen
###### 1624 | ### Do sprach der künig Günther zu seinem capplan ### ez wirt euch wol gebüßt waz euch hat getan ### Hagen in seinem tzorn vnd kum ich an den Rein ### wider mit meinem leben des schüllt ir on angst sein
###### 1625 | ### Vart wider heim ze lande wan– ez muß nu sein ### ich enpewt meinen dienst der liben frawen mein ### vnd andern meinen magen als ich von rechte schol ### ir sagt [107r]in libe mere daz wir noch alle varen wol

<<< Übersicht <<< vorige Seite nächste Seite >>>